@@ -19,6 +19,13 @@ class PaymentCardBrand(str, Enum):
     mastercard = 'Mastercard'
     visa = 'Visa'
     mir = 'Mir'
+    maestro = 'Maestro'
+    discover = 'Discover'
+    verve = 'Verve'
+    dankort = 'Dankort'
+    troy = 'Troy'
+    unionpay = 'UnionPay'
+    jcb = 'JCB'
     other = 'other'
 
     def __str__(self) -> str:
@@ -88,7 +95,7 @@ class PaymentCardNumber(str):
         Raises:
             PydanticCustomError: If the card number is not all digits.
         """
-        if not card_number.isdigit():
+        if not card_number or not all('0' <= c <= '9' for c in card_number):
             raise PydanticCustomError('payment_card_number_digits', 'Card number is not all digits')
 
     @classmethod
@@ -135,37 +142,58 @@ class PaymentCardNumber(str):
         Raises:
             PydanticCustomError: If the card number is not valid.
         """
+        brand = PaymentCardBrand.other
+
         if card_number[0] == '4':
             brand = PaymentCardBrand.visa
+            required_length = [13, 16, 19]
         elif 51 <= int(card_number[:2]) <= 55:
             brand = PaymentCardBrand.mastercard
+            required_length = [16]
         elif card_number[:2] in {'34', '37'}:
             brand = PaymentCardBrand.amex
+            required_length = [15]
         elif 2200 <= int(card_number[:4]) <= 2204:
             brand = PaymentCardBrand.mir
-        else:
-            brand = PaymentCardBrand.other
+            required_length = list(range(16, 20))
+        elif card_number[:4] in {'5018', '5020', '5038', '5893', '6304', '6759', '6761', '6762', '6763'} or card_number[
+            :6
+        ] in (
+            '676770',
+            '676774',
+        ):
+            brand = PaymentCardBrand.maestro
+            required_length = list(range(12, 20))
+        elif card_number.startswith('65') or 644 <= int(card_number[:3]) <= 649 or card_number.startswith('6011'):
+            brand = PaymentCardBrand.discover
+            required_length = list(range(16, 20))
+        elif (
+            506099 <= int(card_number[:6]) <= 506198
+            or 650002 <= int(card_number[:6]) <= 650027
+            or 507865 <= int(card_number[:6]) <= 507964
+        ):
+            brand = PaymentCardBrand.verve
+            required_length = [16, 18, 19]
+        elif card_number[:4] in {'5019', '4571'}:
+            brand = PaymentCardBrand.dankort
+            required_length = [16]
+        elif card_number.startswith('9792'):
+            brand = PaymentCardBrand.troy
+            required_length = [16]
+        elif card_number[:2] in {'62', '81'}:
+            brand = PaymentCardBrand.unionpay
+            required_length = [16, 19]
+        elif 3528 <= int(card_number[:4]) <= 3589:
+            brand = PaymentCardBrand.jcb
+            required_length = [16, 19]
 
-        required_length: None | int | str = None
-        if brand in PaymentCardBrand.mastercard:
-            required_length = 16
-            valid = len(card_number) == required_length
-        elif brand == PaymentCardBrand.visa:
-            required_length = '13, 16 or 19'
-            valid = len(card_number) in {13, 16, 19}
-        elif brand == PaymentCardBrand.amex:
-            required_length = 15
-            valid = len(card_number) == required_length
-        elif brand == PaymentCardBrand.mir:
-            required_length = 'in range from 16 to 19'
-            valid = len(card_number) in range(16, 20)
-        else:
-            valid = True
+        valid = len(card_number) in required_length if brand != PaymentCardBrand.other else True
 
         if not valid:
             raise PydanticCustomError(
                 'payment_card_number_brand',
-                'Length for a {brand} card must be {required_length}',
+                f'Length for a {brand} card must be {" or ".join(map(str, required_length))}',
                 {'brand': brand, 'required_length': required_length},
             )
+
         return brand
